@@ -54,8 +54,7 @@ ggbarstats <- function(data,
                        ggplot.component = NULL,
                        output = "plot",
                        ...) {
-
-  # dataframe ------------------------------------------
+  # data frame ------------------------------------------
 
   # convert entered stats type to a standard notation
   type <- stats_type_switch(type)
@@ -63,12 +62,12 @@ ggbarstats <- function(data,
   # make sure both quoted and unquoted arguments are allowed
   c(x, y) %<-% c(ensym(x), ensym(y))
 
-  # creating a dataframe
+  # creating a data frame
   data %<>%
     select({{ x }}, {{ y }}, .counts = {{ counts }}) %>%
     tidyr::drop_na(.)
 
-  # untable the dataframe based on the count for each observation
+  # untable the data frame based on the count for each observation
   if (".counts" %in% names(data)) data %<>% tidyr::uncount(weights = .counts)
 
   # x and y need to be a factor; also drop the unused levels of the factors
@@ -95,12 +94,12 @@ ggbarstats <- function(data,
       prior.concentration = prior.concentration
     )
 
-    subtitle_df <- eval_f(contingency_table, !!!.f.args, type = type)
+    subtitle_df <- .eval_f(contingency_table, !!!.f.args, type = type)
     if (!is.null(subtitle_df)) subtitle <- subtitle_df$expression[[1]]
 
     # preparing Bayes Factor caption
     if (type != "bayes" && bf.message && isFALSE(paired)) {
-      caption_df <- eval_f(contingency_table, !!!.f.args, type = "bayes")
+      caption_df <- .eval_f(contingency_table, !!!.f.args, type = "bayes")
       if (!is.null(caption_df)) caption <- caption_df$expression[[1]]
     }
   }
@@ -115,14 +114,14 @@ ggbarstats <- function(data,
 
   # plot ------------------------------------------
 
-  # dataframe with summary labels
-  descriptive_df <- descriptive_df(data, {{ x }}, {{ y }}, label, perc.k)
+  # data frame with summary labels
+  descriptive_df <- descriptive_data(data, {{ x }}, {{ y }}, label, perc.k)
 
-  # dataframe containing all details needed for prop test
-  onesample_df <- onesample_df(data, {{ x }}, {{ y }}, k)
+  # data frame containing all details needed for prop test
+  onesample_df <- onesample_data(data, {{ x }}, {{ y }}, k)
 
   # if no. of factor levels is greater than the default palette color count
-  palette_message(package, palette, nlevels(data %>% pull({{ x }})))
+  .palette_message(package, palette, nlevels(data %>% pull({{ x }})))
 
   # plot
   plotBar <- ggplot(descriptive_df, aes({{ y }}, perc, fill = {{ x }})) +
@@ -204,7 +203,7 @@ ggbarstats <- function(data,
 #' library(ggstatsplot)
 #' library(dplyr, warn.conflicts = FALSE)
 #'
-#' # let's create a smaller dataframe
+#' # let's create a smaller data frame
 #' diamonds_short <- ggplot2::diamonds %>%
 #'   filter(cut %in% c("Very Good", "Ideal")) %>%
 #'   filter(clarity %in% c("SI1", "SI2", "VS1", "VS2")) %>%
@@ -226,8 +225,8 @@ grouped_ggbarstats <- function(data,
                                output = "plot",
                                plotgrid.args = list(),
                                annotation.args = list()) {
-  # creating a dataframe
-  data %<>% grouped_list(grouping.var = {{ grouping.var }})
+  # creating a data frame
+  data %<>% .grouped_list(grouping.var = {{ grouping.var }})
 
   # creating a list of return objects
   p_ls <- purrr::pmap(
