@@ -18,7 +18,6 @@ survey_data_NA <- dplyr::tibble(
 test_that(
   desc = "checking default outputs",
   code = {
-    skip_if_not_installed("vdiffr")
     skip_if(getRversion() < "4.1")
 
 
@@ -62,7 +61,6 @@ test_that(
 test_that(
   desc = "changing labels and aesthetics",
   code = {
-    skip_if_not_installed("vdiffr")
     skip_if(getRversion() < "4.1")
 
 
@@ -114,33 +112,34 @@ test_that(
     )
 
     # data
-    df <- structure(list(
-      epoch = structure(
-        c(1L, 2L, 1L, 2L, 1L, 2L, 1L, 2L),
-        .Label = c("Before", "After"),
-        class = "factor"
+    df <- structure(
+      list(
+        epoch = structure(
+          c(1L, 2L, 1L, 2L, 1L, 2L, 1L, 2L),
+          .Label = c("Before", "After"),
+          class = "factor"
+        ),
+        mode = structure(c(1L, 1L, 2L, 2L, 3L, 3L, 4L, 4L),
+          .Label = c("A", "P", "C", "T"), class = "factor"
+        ),
+        counts = c(30916L, 21117L, 7676L, 1962L, 1663L, 462L, 7221L, 197L),
+        perc = c(
+          65.1192181312663,
+          88.9586317297161,
+          16.1681691802174,
+          8.26522874715646,
+          3.50282247872609,
+          1.94624652455978,
+          15.2097902097902,
+          0.829892998567697
+        ),
+        label = c(
+          "65%", "89%", "16%", "8%",
+          "4%", "2%", "15%", "1%"
+        )
       ),
-      mode = structure(c(1L, 1L, 2L, 2L, 3L, 3L, 4L, 4L),
-        .Label = c("A", "P", "C", "T"), class = "factor"
-      ),
-      counts = c(30916L, 21117L, 7676L, 1962L, 1663L, 462L, 7221L, 197L),
-      perc = c(
-        65.1192181312663,
-        88.9586317297161,
-        16.1681691802174,
-        8.26522874715646,
-        3.50282247872609,
-        1.94624652455978,
-        15.2097902097902,
-        0.829892998567697
-      ),
-      label = c(
-        "65%", "89%", "16%", "8%",
-        "4%", "2%", "15%", "1%"
-      )
-    ),
-    row.names = c(NA, -8L),
-    class = c("tbl_df", "tbl", "data.frame")
+      row.names = c(NA, -8L),
+      class = c("tbl_df", "tbl", "data.frame")
     )
 
     set.seed(123)
@@ -163,7 +162,6 @@ test_that(
 test_that(
   desc = "edge cases",
   code = {
-    skip_if_not_installed("vdiffr")
     skip_if(getRversion() < "4.1")
 
 
@@ -200,7 +198,7 @@ test_that(
     )
 
     set.seed(123)
-    stats_output <- suppressWarnings(statsExpressions::contingency_table(
+    stats_output <- suppressWarnings(contingency_table(
       data = ggplot2::msleep,
       x = conservation,
       y = vore,
